@@ -1,7 +1,7 @@
 //
 // dell.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012-2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -37,4 +37,14 @@ public:
     QObject *guiObject);
 };
 
+class DellProjector1: public PIRKeysetMetaData
+{
+public:
+  DellProjector1(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
 #endif // DELL_H
