@@ -51,6 +51,7 @@ enum PIRKeyName
   QuickMenu_Key,
   AppsMenu_Key,
   ToolsMenu_Key,
+  CECMenu_Key,
 
   // Number keys:
   Zero_Key,
@@ -258,7 +259,7 @@ enum PIRKeyName
   Oscillate_Key,
   FanFaster_Key,
   FanSlower_Key,
-  EnergySave_Key,
+  EnergySave_Key, // Also used for TVs with E-save mode!
 
   // Stateful A/C controls:
   ACSendCommand_Key,
